@@ -565,28 +565,28 @@ class Sherlock:
         clean_time, flatten_flux, clean_flux_err = self.__clean_initial_flux(object_info, lc.time, lc.flux, lc.flux_err,
                                                                              star_info, cadence)
         lc = lk.LightCurve(time=clean_time, flux=flatten_flux, flux_err=clean_flux_err)
-        period = None
+        self.rotator_period = None
         periodogram = lc.to_periodogram(minimum_period=self.wl_min[sherlock_id], oversample_factor=10)
         periodogram.plot(view='period', scale='log')
         plt.title(str(sherlock_id) + " Lightcurve periodogram")
         plt.savefig(object_dir + "Periodogram_" + str(sherlock_id) + ".png")
         plt.clf()
         if object_info.initial_detrend_period is not None:
-            period = object_info.initial_detrend_period
+            self.rotator_period = object_info.initial_detrend_period
         elif self.auto_detrend_periodic_signals:
-            period = self.__calculate_max_significant_period(lc, periodogram)
-        if period is not None:
+            self.rotator_period = self.__calculate_max_significant_period(lc, periodogram)
+        if self.rotator_period is not None:
             logging.info('================================================')
             logging.info('AUTO-DETREND EXECUTION')
             logging.info('================================================')
-            logging.info("Period = %.3f", period)
-            lc.fold(period).scatter()
-            plt.title("Phase-folded period: " + format(period, ".2f") + " days")
-            plt.savefig(object_dir + "Phase_detrend_period_" + str(sherlock_id) + "_" + format(period, ".2f") + "_days.png")
+            logging.info("Period = %.3f", self.rotator_period)
+            lc.fold(self.rotator_period).scatter()
+            plt.title("Phase-folded period: " + format(self.rotator_period, ".2f") + " days")
+            plt.savefig(object_dir + "Phase_detrend_period_" + str(sherlock_id) + "_" + format(self.rotator_period, ".2f") + "_days.png")
             plt.clf()
-            flatten_flux, lc_trend = self.__detrend_by_period(clean_time, flatten_flux, period * self.auto_detrend_ratio)
+            flatten_flux, lc_trend = self.__detrend_by_period(clean_time, flatten_flux, self.rotator_period * self.auto_detrend_ratio)
             if not self.period_min:
-                self.period_min = period * 4
+                self.period_min = self.rotator_period * 4
                 logging.info("Setting Min Period to %.3f", self.period_min)
         if object_info.initial_mask is not None:
             logging.info('================================================')
